@@ -22,6 +22,7 @@ import glob
 import os
 import logging
 import socket
+import urllib
 
 from gi.repository import Gio
 from gi.repository import GObject
@@ -34,7 +35,8 @@ from .baseclass import vmmGObjectUI
 HV_XEN,
 HV_LXC,
 HV_QEMU_SESSION,
-HV_BHYVE) = range(5)
+HV_BHYVE,
+HV_VZ) = range(6)
 
 (CONN_SSH,
 CONN_TCP,
@@ -45,7 +47,7 @@ def current_user():
     try:
         import getpass
         return getpass.getuser()
-    except:
+    except Exception:
         return ""
 
 
@@ -98,7 +100,7 @@ class vmmConnect(vmmGObjectUI):
             # Call any API, so we detect if avahi is even available or not
             self.avahiserver.GetAPIVersion()
             logging.debug("Connected to avahi")
-        except Exception, e:
+        except Exception as e:
             self.dbus = None
             self.avahiserver = None
             logging.debug("Couldn't contact avahi: %s", str(e))
@@ -165,10 +167,11 @@ class vmmConnect(vmmGObjectUI):
                 model.append([rowid, label])
 
         _add_hv_row(HV_QEMU, "qemu", "QEMU/KVM")
-        _add_hv_row(HV_QEMU_SESSION, "qemu", "QEMU/KVM user session")
+        _add_hv_row(HV_QEMU_SESSION, "qemu", "QEMU/KVM " + _("user session"))
         _add_hv_row(HV_XEN, "xen", "Xen")
-        _add_hv_row(HV_LXC, "lxc", "LXC (Linux Containers)")
+        _add_hv_row(HV_LXC, "lxc", "LXC (" + _("Linux Containers") + ")")
         _add_hv_row(HV_BHYVE, "bhyve", "Bhyve")
+        _add_hv_row(HV_VZ, "vz", "Virtuozzo")
         combo.set_model(model)
         uiutil.init_combo_text_column(combo, 1)
 
@@ -176,7 +179,7 @@ class vmmConnect(vmmGObjectUI):
         model = Gtk.ListStore(str)
         model.append(["SSH"])
         model.append(["TCP (SASL, Kerberos)"])
-        model.append(["SSL/TLS with certificates"])
+        model.append(["SSL/TLS " + _("with certificates")])
         combo.set_model(model)
         uiutil.init_combo_text_column(combo, 0)
 
@@ -206,9 +209,9 @@ class vmmConnect(vmmGObjectUI):
     def set_default_hypervisor(self):
         default = self.default_uri()
         if not default or default.startswith("qemu"):
-            uiutil.select_list_row_by_value(self.widget("hypervisor"), HV_QEMU)
+            uiutil.set_list_selection(self.widget("hypervisor"), HV_QEMU)
         elif default.startswith("xen"):
-            uiutil.select_list_row_by_value(self.widget("hypervisor"), HV_XEN)
+            uiutil.set_list_selection(self.widget("hypervisor"), HV_XEN)
 
     def add_service(self, interface, protocol, name, typ, domain, flags):
         ignore = flags
@@ -230,7 +233,7 @@ class vmmConnect(vmmGObjectUI):
 
             sig = resint.connect("g-signal", cb)
             self.browser_sigs.append((resint, sig))
-        except Exception, e:
+        except Exception as e:
             logging.exception(e)
 
     def remove_service(self, interface, protocol, name, typ, domain, flags):
@@ -246,7 +249,7 @@ class vmmConnect(vmmGObjectUI):
             for row in model:
                 if row[0] == name:
                     model.remove(row.iter)
-        except Exception, e:
+        except Exception as e:
             logging.exception(e)
 
     def add_conn_to_list(self, interface, protocol, name, typ, domain,
@@ -269,7 +272,7 @@ class vmmConnect(vmmGObjectUI):
 
             host = self.sanitize_hostname(str(host))
             model.append([str(address), str(host), str(name)])
-        except Exception, e:
+        except Exception as e:
             logging.exception(e)
 
     def start_browse(self):
@@ -327,7 +330,9 @@ class vmmConnect(vmmGObjectUI):
         self.populate_uri()
 
     def hypervisor_changed(self, src):
-        is_session = (src.get_active() == HV_QEMU_SESSION)
+        ignore = src
+        hv = uiutil.get_list_selection(self.widget("hypervisor"))
+        is_session = (hv == HV_QEMU_SESSION)
         uiutil.set_grid_row_visible(
             self.widget("session-warning-box"), is_session)
         uiutil.set_grid_row_visible(
@@ -369,7 +374,7 @@ class vmmConnect(vmmGObjectUI):
         self.widget("username-entry").set_text(default_user)
 
     def generate_uri(self):
-        hv = uiutil.get_list_selection(self.widget("hypervisor"), 0)
+        hv = uiutil.get_list_selection(self.widget("hypervisor"))
         conn = self.widget("transport").get_active()
         host = self.widget("hostname").get_child().get_text().strip()
         user = self.widget("username-entry").get_text()
@@ -382,12 +387,17 @@ class vmmConnect(vmmGObjectUI):
             hvstr = "qemu"
         elif hv == HV_BHYVE:
             hvstr = "bhyve"
+        elif hv == HV_VZ:
+            hvstr = "vz"
         else:
             hvstr = "lxc"
 
         addrstr = ""
         if user:
-            addrstr += user + "@"
+            addrstr += urllib.quote(user) + "@"
+
+        if host.count(":") > 1:
+            host = "[%s]" % host
         addrstr += host
 
         hoststr = ""
@@ -403,7 +413,7 @@ class vmmConnect(vmmGObjectUI):
             hoststr += addrstr + "/"
 
         uri = hvstr + hoststr
-        if hv in (HV_QEMU, HV_BHYVE):
+        if hv in (HV_QEMU, HV_BHYVE, HV_VZ):
             uri += "system"
         elif hv == HV_QEMU_SESSION:
             uri += "session"
@@ -462,7 +472,7 @@ class vmmConnect(vmmGObjectUI):
             elif self.can_resolve_local is None:
                 try:
                     socket.getaddrinfo(host, None)
-                except:
+                except Exception:
                     logging.debug("Couldn't resolve host '%s'. Stripping "
                                   "'.local' and retrying.", host)
                     self.can_resolve_local = False
@@ -476,7 +486,7 @@ class vmmConnect(vmmGObjectUI):
             elif self.can_resolve_hostname is None:
                 try:
                     socket.getaddrinfo(host, None)
-                except:
+                except Exception:
                     logging.debug("Couldn't resolve host '%s'. Disabling "
                                   "host name resolution, only using IP addr",
                                   host)
